@@ -1447,6 +1447,7 @@ def MH_SS_without_DA(y, x, V, x0, nburn, npost, model, implementation, control_v
                     r = r + 0.5 * (theta_prime - theta_hat) @ sum_hess_at_theta_hat @ (theta_prime - theta_hat) - 0.5 * (theta - theta_hat) @ sum_hess_at_theta_hat @ (theta - theta_hat)
             else:
                 r = 0 # accept theta_prime
+                log_ratio1 = 0
 
         # Perform a RWM step
         elif poisson_rate >= n:
@@ -1465,7 +1466,7 @@ def MH_SS_without_DA(y, x, V, x0, nburn, npost, model, implementation, control_v
                 log_ratio1 = 0 # move on
             # If the acceptance probability PART 1 is all right, then work away
             if log_ratio1 is not None:
-            # if np.random.exponential() > -log_ratio1 or log_ratio1 is not None:
+            # if np.random.exponential() > -log_ratio1:
                 if i >= nburn:
                     count_acc_rate_ratio1 = count_acc_rate_ratio1 + 1
 
@@ -1515,7 +1516,7 @@ def MH_SS_without_DA(y, x, V, x0, nburn, npost, model, implementation, control_v
             else:
                 r = -np.Inf # i.e., reject theta_prime
 
-        if np.random.exponential() > -r:
+        if np.random.exponential() > -(r + log_ratio1):
             aux_theta_SJD = theta
             theta = theta_prime
             if i>= nburn:
